@@ -6,7 +6,7 @@ from __future__ import annotations
 
 import os
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Type
+from typing import TYPE_CHECKING, Any, Type
 from zipfile import ZipFile
 
 import numpy as np
@@ -53,6 +53,14 @@ class DTMProvider(ABC):
 
     _base_instructions = None
 
+    # AdvancedSettings that should be changed by the DTM Provider if it's selected.
+    # * This feature has effect only in the WebUI of the app and ignored in Python package.
+    # The first level of the dictionary is a category name,
+    # for example: TextureSettings, DEMSettings, etc.
+    # The second level is a name of particular setting in the category.
+    # Example: {"DEMSettings": {"blur_radius": 35}}
+    _default_settings: dict[str, dict[str, Any]] = {}
+
     def __init__(
         self,
         coordinates: tuple[float, float],
@@ -74,7 +82,14 @@ class DTMProvider(ABC):
         self.logger = logger
         self.map = map
 
-        self._data_info: dict[str, int | str | float] | None = None
+    @classmethod
+    def default_settings(cls) -> dict[str, dict[str, Any]]:
+        """Default settings of the provider.
+
+        Returns:
+            dict: Default settings of the provider.
+        """
+        return cls._default_settings
 
     @classmethod
     def name(cls) -> str | None:
@@ -94,24 +109,6 @@ class DTMProvider(ABC):
         """
         return cls._code
 
-    @property
-    def data_info(self) -> dict[str, int | str | float] | None:
-        """Information about the DTM data.
-
-        Returns:
-            dict[str, int | str | float] | None: Information about the DTM data.
-        """
-        return self._data_info
-
-    @data_info.setter
-    def data_info(self, value: dict[str, int | str | float] | None) -> None:
-        """Set information about the DTM data.
-
-        Arguments:
-            value (dict[str, int | str | float] | None): Information about the DTM data.
-        """
-        self._data_info = value
-
     @property
     def coordinates(self) -> tuple[float, float]:
         """Coordinates of the center point of the DTM data.
@@ -330,16 +327,6 @@ class DTMProvider(ABC):
 
         return data
 
-    def info_sequence(self) -> dict[str, int | str | float] | None:
-        """Returns the information sequence for the component. Must be implemented in the child
-        class. If the component does not have an information sequence, an empty dictionary must be
-        returned.
-
-        Returns:
-            dict[str, int | str | float] | None: Information sequence for the component.
-        """
-        return self.data_info
-
     # region helpers
     def get_bbox(self) -> tuple[float, float, float, float]:
         """Get bounding box of the tile based on the center point and size.
@@ -417,17 +404,31 @@ class DTMProvider(ABC):
 
         Returns:
             str: Path to the unzipped file.
+
+        Raises:
+            FileNotFoundError: If no .img or .tif file is found in the zip file
         """
         file_path = os.path.join(output_path, file_name)
         img_file_name = file_name.replace(".zip", ".img")
+        tif_file_name = file_name.replace(".zip", ".tif")
         img_file_path = os.path.join(output_path, img_file_name)
-        if not os.path.exists(img_file_path):
-            with ZipFile(file_path, "r") as f_in:
-                f_in.extract(img_file_name, output_path)
-            self.logger.debug("Unzipped file %s to %s", file_name, img_file_name)
-        else:
+        tif_file_path = os.path.join(output_path, tif_file_name)
+        if os.path.exists(img_file_path):
             self.logger.debug("File already exists: %s", img_file_name)
-        return img_file_path
+            return img_file_path
+        if os.path.exists(tif_file_path):
+            self.logger.debug("File already exists: %s", tif_file_name)
+            return tif_file_path
+        with ZipFile(file_path, "r") as f_in:
+            if img_file_name in f_in.namelist():
+                f_in.extract(img_file_name, output_path)
+                self.logger.debug("Unzipped file %s to %s", file_name, img_file_name)
+                return img_file_path
+            if tif_file_name in f_in.namelist():
+                f_in.extract(tif_file_name, output_path)
+                self.logger.debug("Unzipped file %s to %s", file_name, tif_file_name)
+                return tif_file_path
+        raise FileNotFoundError("No .img or .tif file found in the zip file.")
 
     def reproject_geotiff(self, input_tiff: str) -> str:
         """Reproject a GeoTIFF file to a new coordinate reference system (CRS).
